@@ -1,8 +1,11 @@
+{-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE RecordWildCards #-}
 {-# OPTIONS_HADDOCK hide #-}
 
 -- | Helper functions for rendering bitmaps
 module Graphics.Gloss.Internals.Rendering.Bitmap
-        ( BitmapData(..)
+        ( Rectangle(..)
+        , BitmapData(..)
         , BitmapFormat(..), PixelFormat(..), RowOrder(..)
         , bitmapPath
         , freeBitmapData)
@@ -11,12 +14,22 @@ import Data.Data
 import Foreign
 
 
+-- | Represents a rectangular section in a bitmap
+data Rectangle
+        = Rectangle
+        { rectPos :: (Int, Int) -- ^ x- and y-pos in the bitmap in pixels
+        , rectSize :: (Int, Int) -- ^ width/height of the area in pixelsi
+        }
+        deriving (Show, Read, Eq, Ord, Data, Typeable)
+
 -- | Abstract 32-bit RGBA bitmap data.
 data BitmapData
         = BitmapData
         { bitmapDataLength :: Int  -- length (in bytes)
         , bitmapFormat     :: BitmapFormat
-        , bitmapPointer    :: (ForeignPtr Word8) } 
+        , bitmapSize       :: (Int, Int) -- ^ width, height in pixels
+        , bitmapCacheMe    :: Bool
+        , bitmapPointer    :: (ForeignPtr Word8) }
         deriving (Eq, Data, Typeable)
 
 
@@ -25,7 +38,7 @@ data BitmapData
 --   * Prior version of Gloss assumed `BitmapFormat BottomToTop PxAGBR`
 --
 data BitmapFormat
-        = BitmapFormat 
+        = BitmapFormat
         { rowOrder    :: RowOrder
         , pixelFormat :: PixelFormat }
         deriving (Eq, Data, Typeable, Show, Ord)
@@ -37,7 +50,7 @@ data BitmapFormat
 --   * `BottomToTop` - the bottom row followed by the next-higher row and so on.
 --
 data RowOrder
-        = TopToBottom 
+        = TopToBottom
         | BottomToTop
         deriving (Eq, Data, Typeable, Show, Ord, Enum, Bounded)
 
@@ -47,7 +60,6 @@ data PixelFormat
         = PxRGBA | PxABGR
         deriving (Eq, Data, Typeable, Show, Ord, Enum, Bounded)
 
-
 instance Show BitmapData where
  show _ = "BitmapData"
 
