@@ -7,7 +7,7 @@ import qualified Graphics.Rendering.OpenGL.GL           as GL
 
 
 -- | Convert one of our Colors to OpenGL's representation.
-glColor4OfColor :: Fractional a => Color -> GL.Color4 a
+glColor4OfColor :: Color -> GL.Color4 a
 glColor4OfColor color
  = case color of
         RGBA r g b a
